@@ -825,7 +825,10 @@ $LANG24 = array(
     85 => 'Nita kik',
     86 => 'Keerukam toimetaja',
     87 => 'Lugude statistika',
-    88 => 'Wiki-laadne formaat'
+    88 => 'Wiki-laadne formaat',
+    89 => 'Meta kirjeldus',
+    90 => 'Meta mrksnad',
+    91 => 'Sa vid alati klpsata "Eelvaade", et aegumisaega pikendada.'
 );
 
 ###############################################################################
@@ -860,7 +863,8 @@ $LANG27 = array(
     26 => 'mra see rubriik arhiveeritud lugude  jaoks vaikerubriigiks. Ainult ks rubriik on lubatud.',
     27 => 'vi lae rubriigi ikoon',
     28 => 'Maksimum',
-    29 => 'Vead faili leslaadimisel'
+    29 => 'Vead faili leslaadimisel',
+    30 => 'Lood rubriikides'
 );
 
 ###############################################################################
@@ -1022,7 +1026,7 @@ $LANG31 = array(
 
 $LANG32 = array(
     1 => 'Pluginate installeerimine vib kahjustada sinu Geeklogi installatsiooni ja lisaks kahjustada ka sinu ssteemi. On oluline, et sa installeeriksid vaid <a href="http://www.geeklog.net">Geeklogi kodulehelt</a> laetud pluginaid, sest me kontrollime hoolikalt meie lehele laetud pluginaid erinevates operatsioonissteemides. On oluline mista, et plugina installeerimine nuab mitmete ssteemikskude kasutamist, mis vib kaasa tuua turvalisusprobleeme, eriti siis, kui sa kasutad kolmandatelt lehtedelt laetud pluginaid. Sellest hoiatusest hoolimata ei taga me plugina installeerimise edukust ega vastuta selle installeerimise tagajrjena phjustatud kahju eest. Teiste snadega - installeeri oma vastutusel. Lisaks on iga plugina paketi juures juhend, kuidas installeerida plugin ksitsi.',
-    2 => 'Plug-in Installation Disclaimer',
+    2 => 'Plug-ina installeerimise disklaimer',
     3 => 'Plugina installeerimisvorm',
     4 => 'Plugina fail',
     5 => 'Pluginate loetelu',
@@ -1062,6 +1066,7 @@ $LANG32 = array(
     39 => 'Lae plugin',
     40 => 'Sa vid otse siin laadida plugina arhiivi (.tar.gz, .tgz, .zip):',
     41 => 'Lae lesse',
+    42 => 'Click to update',
     99 => 'Oli tundmatu viga',
     100 => 'OK.',
     101 => 'lesse laetud faili suurus letab php.ini failis oleva upload_max_filesize direktiivi.',
@@ -1323,7 +1328,26 @@ $LANG_DB_BACKUP = array(
     'size' => 'suurus',
     'bytes' => 'baiti',
     'total_number' => 'Varunduste ldarv: %d',
-    'download' => 'Klpsa selle faili allalaadimiseks'
+    'download' => 'Klpsa selle faili allalaadimiseks',
+    'new_backup' => 'Uus varundamine',
+    'delete_failure' => 'he vi enama backupfaili kustutamine ebannestus.',
+    'delete_success' => 'Backupfail(id) on edukalt kustutatud.',
+    'convert_menu' => 'Konverteeri InnoDB formaati',
+    'convert_title' => 'Konverteeri InnoDB tabeliteks',
+    'convert_button' => 'Konverteeri',
+    'sorry_no_innodb' => 'Kahjuks sinu MySQL-i versioon ei toeta  InnoDB tabeleid.',
+    'innodb_explain' => 'InnoDB tabelid pakuvad suuremat judlust, kui tegu on <em>testi</em> suure andmebaasiga, kuid teeb varundamise protsessi keerulisemaks. Palun <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">loe rohkem </a> InnoDB tabelite kohta kivate poolt ja vastuargumente, enne kui teostad selle operatsiooni.',
+    'already_converted' => 'Mrkus: Nib, et kik tabelid on juba konverteeritud InnoDB tabeliteks.',
+    'conversion_patience' => 'Mrkus: Konverteerimine vib vtta aega. Palun kannatust.',
+    'innodb_success' => 'Tabelid on edukalt konverteeritud InnoDB formaati.',
+    'table_issues' => 'Mnede tabelitega vis olla probleeme. Vaata tpsemat infot error.log failist. .',
+    'optimize_menu' => 'Optimeeri tabeleid',
+    'optimize_title' => 'Optimeeri tabeleid',
+    'optimize_button' => 'Optimeeri',
+    'optimize_explain' => 'Tabelite optimeerimine vib parandada saidi judlust. Tegelik kasu sltub iga tabeli kasutusest ja mnede tabelite puhul annab see rohkem kasu kui teiste puhul. ra oota teliselt suurt judluse tusu. <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manuaal </a> tleb: <q>Ei ole tenoline, et sa peaksid seda tegema sagedamini kui korra kuus vi ndalas</q>.',
+    'last_optimization' => 'Viimane optimeerimine',
+    'optimization_patience' => 'Mrkus: Optimeerimine vib vtta aega. Palun kannatust.',
+    'optimize_success' => 'Andmebaasi tabelite optimeerimine oli edukas.'
 );
 
 ###############################################################################
@@ -1472,7 +1496,7 @@ $LANG_SECTEST = array(
     'public_html' => '"public_html" ei tohiks kunagi olla osa  sinu saidi URList.  Palun loe public_html kohta kivat osa %s uuesti ja muuda enne jtkamist vastavalt lehe seadistust.',
     'installation' => 'Installeerimisjuhised',
     'directory' => 'Kaust',
-    'failed_bak' => 'Ebannestus data kausta ajutiste failide kausta loomine. Kontrolli kausta igusi!',
+    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
     'fix_it' => 'See on turvarisk ja see tuleb parandada!',
     'reachable' => 'Sinu %s on veebist kttesaadav.',
     'not_reachable' => 'Hea! Sinu %s pole veebist kttesaadav.',
@@ -1572,7 +1596,10 @@ $LANG_ADMIN = array(
     'addchild' => 'Lisa alamdetail',
     'list' => 'Loetelu',
     'list_all' => 'Loetle kik',
-    'na' => 'N/A'
+    'meta_description' => 'Meta kirjeldus',
+    'meta_keywords' => 'Meta mrksnad',
+    'na' => 'N/A',
+    'token_expiry' => 'Sul on aega kuni %s, et teha muutusi. Prast seda aegub lehele lisatud turvalisuskood ja tehtud muutused lhevad kaotsi.'
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1838,17 +1865,22 @@ $LANG_confignames['Core'] = array(
     'disable_autolinks' => 'Keela autolingid?',
     'clickable_links' => 'Tee URL-id klikitavaks?',
     'compressed_output' => 'Saada vljund tihendatult?',
+    'frame_options' => 'Kaitse "clickjacking" vastu',
     'censormode' => 'Tsensuurireiim?',
     'censorreplace' => 'Tsensuuri asendustekst',
     'censorlist' => 'Tsenseerimisloetelu',
     'ip_lookup' => 'IP otsing',
     'url_rewrite' => 'Luba URL-i lekirjutamine',
+    'meta_tags' => 'Meta Tags',
+    'meta_description' => 'Default Meta Description',
+    'meta_keywords' => 'Default Meta Keywords',
     'default_permissions_block' => 'Bloki vaikimisi igused',
     'default_permissions_story' => 'Lugude vaikimisi igused',
     'default_permissions_topic' => 'Rubriigi vaikimisi igused',
     'atom_max_stories' => 'Maks. lugusid veebiteenuste limedes',
     'disable_webservices' => 'Keela veebiteenused?',
     'restrict_webservices' => 'Piira veebiteenused?',
+    'article_comment_close_enabled' => 'Automatically close comments (default)',
     'article_comment_close_days' => 'Sulge kommenteerimine pevaga (vaikimisi)',
     'comment_close_rec_stories' => 'Uusimate lugude arv, mida on lubatud kommenteerida',
     'allow_reply_notifications' => 'Luba kommentaarile vastamisest teavitamine?',
@@ -1859,8 +1891,7 @@ $LANG_confignames['Core'] = array(
     'search_show_sort' => 'Luba kasutajal tulemusi sorteerida?',
     'search_show_limit' => 'Nita lehe limiiti?',
     'search_separator' => 'Grupi eraldaja',
-    'search_def_keytype' => 'Vaikimisi otsimisviis',
-    'frame_options' => 'Kaitse "clickjacking" vastu'
+    'search_def_keytype' => 'Vaikimisi otsimisviis'
 );
 
 $LANG_configsubgroups['Core'] = array(
@@ -1941,9 +1972,8 @@ $LANG_configselects['Core'] = array(
     19 => array('Google' => 'google', 'Tabel' => 'table'),
     20 => array('Tpne fraas' => 'phrase', 'Kik snad' => 'all', 'Mni snadest' => 'any'),
     21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
-        22 => array('Range' => 'DENY', 'Sama allikas' => 'SAMEORIGIN',
-'(vljas)' => '')
-
+    22 => array('Range' => 'DENY', 'Sama allikas' => 'SAMEORIGIN', '(vljas)' => ''),
+    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2)
 );
 
 ?>
