@@ -85,7 +85,7 @@ $LANG01 = array(
     37 => 'Keine Artikel.',
     38 => 'Newsfeed',
     39 => 'Neuladen',
-    40 => 'Sie haben <tt>register_globals = Off</tt> in Ihrer <tt>php.ini</tt>. Fr Geeklog muss <tt>register_globals</tt> jedoch auf <strong>on</strong> stehen. Bitte ndern Sie dies auf <strong>on</strong> und starten Sie Ihren Webserver neu.',
+    40 => 'Auf dem Webserver ist <tt>register_globals = Off</tt>. Fr Geeklog muss <tt>register_globals</tt> jedoch auf <strong>on</strong> stehen. Bitte dies vom Hoster ndern lassen auf <strong>on</strong>.',
     41 => 'Gste',
     42 => 'Autor:',
     43 => 'Antwort schreiben',
@@ -93,12 +93,12 @@ $LANG01 = array(
     45 => 'MySQL Fehlernummer',
     46 => 'MySQL Fehlermeldung',
     47 => 'Anmelden',
-    48 => 'Ihr Profil',
+    48 => 'Mein Profil',
     49 => 'Einstellungen',
     50 => 'Fehler im SQL-Befehl',
     51 => 'Hilfe',
     52 => 'Neu',
-    53 => 'Admin-Home',
+    53 => 'Schaltzentrale',
     54 => 'Konnte die Datei nicht ffnen:',
     55 => 'Fehler in',
     56 => 'Abstimmen',
@@ -170,7 +170,7 @@ $LANG01 = array(
     122 => 'Trackbacks (%d)',
     123 => 'Alle HTML-Tags sind erlaubt',
     124 => 'Alle angekreuzten Eintrge lschen',
-    125 => 'Sind Sie sicher, dass Sie alle angekreuzten Eintrge lschen wollen?',
+    125 => 'Sollen alle angekreuzten Eintrge wirklich gelscht werden?',
     126 => 'Alle Eintrge ankreuzen oder deselektieren',
     127 => 'Permalink',
     128 => 'Einloggen mit OpenID:',
@@ -200,31 +200,31 @@ $LANG03 = array(
     16 => 'Betreff',
     17 => 'Fehler',
     18 => 'Wichtige Hinweise:',
-    19 => 'Bitte geben Sie nur Kommentare ab, die zum Thema gehren.',
+    19 => 'Bitte nur Kommentare abgeben, die zum Thema gehren.',
     20 => 'Beziehen Sie sich mglichst auf Kommentare anderer Personen statt einen neuen Thread zu erffnen.',
     21 => 'Lesen Sie bitte die vorhandenen Kommentare bevor Sie Ihren eigenen abgeben, um nicht noch einmal zu schreiben, was schon gesagt wurde.',
     22 => 'Benutzen Sie eine eindeutige Betreffzeile, die den Inhalt Ihres Kommentars zusammenfasst.',
     23 => 'Ihre E-Mail-Adresse wird NICHT verffentlicht.',
     24 => 'Gast',
-    25 => 'Sind Sie sicher, dass Sie diesen Beitrag als mglichen Missbrauch melden wollen?',
+    25 => 'Soll dieser Beitrag wirklich als mglicher Missbrauch gemeldet werden?',
     26 => '%s meldete den folgenden Beitrag als mglichen Missbrauch:',
     27 => 'Hinweis auf Missbrauch',
-    28 => 'Preview Changes',
-    29 => 'Submit Changes',
-    30 => 'Edited on',
-    31 => 'by',
-    32 => 'Editing a Comment',
-    33 => 'Editing a Comment Submission',
-    34 => 'Preview Submission Changes',
-    35 => 'Save Changes to Queue',
-    36 => 'Notify me of new replies',
-    37 => 'New Comment Reply',
-    38 => 'A reply has been made to your comment \'%s\'.',
-    39 => 'You may view the comment thread at the following address:',
-    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
-    41 => 'Hello %s,',
-    42 => 'Unsubscribe',
-    43 => 'Unsubscribe from reply notifications'
+    28 => 'Vorschau der nderungen',
+    29 => 'nderungen speichern',
+    30 => 'Editiert am',
+    31 => 'von',
+    32 => 'Kommentar editieren',
+    33 => 'Eingereichten Kommentar editieren',
+    34 => 'Vorschau der nderungen',
+    35 => 'nderungen abspeichern',
+    36 => 'Mich bei Antworten benachrichtigen',
+    37 => 'Neue Antwort auf Kommentar',
+    38 => 'Eine Antwort ist eingegangen auf den Kommentar \'%s\'.',
+    39 => 'Den Kommentar-Thread kann man an folgender Adresse sehen:',
+    40 => 'Wenn keine weiteren Benachrichtigungen gewnscht sind, dann bitte folgenden Link besuchen:',
+    41 => 'Hallo %s,',
+    42 => 'Abmelden',
+    43 => 'Abmelden von Benachrichtigungen auf Kommentare'
 );
 
 ###############################################################################
@@ -259,8 +259,8 @@ $LANG04 = array(
     26 => 'Geben Sie <em>entweder</em> Ihren Usernamen <em>oder</em> die E-Mail-Adresse ein, mit der Sie sich angemeldet haben, und klicken Sie dann auf "Passwort schicken". Eine E-Mail mit einer Anleitung, wie Sie ein neues Passwort eingeben knnen, wird dann an die gespeicherte E-Mail-Adresse geschickt.',
     27 => 'Jetzt anmelden!',
     28 => 'Passwort schicken',
-    29 => 'logged out from',
-    30 => 'logged in from',
+    29 => 'ausgeloggt von',
+    30 => 'eingeloggt von',
     31 => 'Um diese Funktion nutzen zu knnen, mssen Sie angemeldet sein',
     32 => 'Signatur',
     33 => 'Auf der Site nicht sichtbar!',
@@ -326,8 +326,8 @@ $LANG04 = array(
     93 => 'Sie haben zuletzt vor %d Sekunden ein neues Passwort angefordert. Zwischen zwei Passwort-Anforderungen mssen aber mindestens %d Sekunden vergangen sein.',
     94 => 'Account "%s" lschen',
     95 => 'Sie knnen Ihren Account lschen, indem Sie auf den "Account Lschen"-Button klicken. Artikel und Kommentare, die Sie unter diesem Account geschrieben haben, werden <strong>nicht</strong> gelscht, werden aber fortan als vom User "Gast" geschrieben erscheinen.',
-    96 => 'Account Lschen',
-    97 => 'Account Lschen besttigen',
+    96 => 'Account lschen',
+    97 => 'Account lschen besttigen',
     98 => 'Sind Sie sicher, dass Sie Ihren Account lschen wollen? Sie werden sich danach nicht mehr einloggen knnen (es sei denn, Sie legen einen neuen Account an). Wenn Sie sich sicher sind, klicken Sie bitte noch einmal auf "Account Lschen".',
     99 => 'Privatsphre-Einstellungen fr',
     100 => 'E-Mail von Admin',
@@ -339,7 +339,7 @@ $LANG04 = array(
     106 => 'Wohnort',
     107 => 'Erscheint im ffentlichen Profil',
     108 => 'Neues Passwort besttigen',
-    109 => 'Geben Sie hier das neue Passwort noch einmal ein',
+    109 => 'Hier bitte das neue Passwort noch einmal eingeben',
     110 => 'Aktuelles Passwort',
     111 => 'Geben Sie Ihr aktuelles Passwort ein',
     112 => 'Sie haben die erlaubte Anzahl von Anmeldeversuchen berschritten. Bitte versuchen Sie es spter noch einmal.',
@@ -408,7 +408,7 @@ $LANG_MYACCOUNT = array(
 
 $LANG05 = array(
     1 => 'Keine Artikel',
-    2 => 'Es gibt keine Artikel, die angezeigt werden knnten. Entweder gibt es fr diese Kategorie keine Artikel oder Ihre Einstellungen sind zu restriktiv.',
+    2 => 'Es gibt keine Artikel, die angezeigt werden knnten. Entweder gibt es fr diese Kategorie keine Artikel oder die persnlichen Einstellungen sind zu restriktiv.',
     3 => ' fr die Kategorie %s.',
     4 => 'Hauptartikel',
     5 => 'weiter',
@@ -456,9 +456,9 @@ $LANG08 = array(
     33 => 'Kompletter Artikel unter',
     34 => 'Ende dieser Nachricht',
     35 => 'Sorry, dieser User mchte keine E-Mails bekommen.',
-    36 => 'Copy:',
-    37 => 'Send me a copy of this email',
-    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
+    36 => 'Kopie:',
+    37 => 'Ich mchte eine Kopie der E-Mail bekommen',
+    38 => "Dies ist eine Kopie der E-Mail, die Sie von <{$_CONF['site_url']}> an %s gesendet haben:"
 );
 
 ###############################################################################
@@ -478,12 +478,12 @@ $LANG09 = array(
     11 => 'Suchergebnisse',
     12 => 'Treffer',
     13 => 'Erweiterte Suche: Keine Treffer',
-    14 => 'Es gab keine Treffer fr Ihre Suche nach',
+    14 => 'Es gab keine Treffer fr die Suche nach',
     15 => 'Bitte noch einmal versuchen.',
     16 => 'Titel',
     17 => 'Datum',
     18 => 'Autor',
-    19 => "Durchsuchen Sie die komplette Datenbank von {$_CONF['site_name']} ...",
+    19 => "Durchsuche die komplette Datenbank von {$_CONF['site_name']} ...",
     20 => 'Datum',
     21 => 'bis',
     22 => '(Datumsformat: JJJJ-MM-TT)',
@@ -505,7 +505,7 @@ $LANG09 = array(
     38 => '',
     39 => '',
     40 => '',
-    41 => 'Ihr Suchbegriff sollte mindestens 3 Zeichen lang sein.',
+    41 => 'Der Suchbegriff sollte mindestens 3 Zeichen lang sein.',
     42 => 'Das Datum muss im Format JJJJ-MM-TT (Jahr-Monat-Tag) eingegeben werden.',
     43 => 'genaue Wortgruppe',
     44 => 'alle Wrter',
@@ -614,7 +614,7 @@ $LANG12 = array(
     22 => 'Fehler: Nicht alle Felder ausgefllt',
     23 => 'Bitte alle Felder des Formulars ausfllen. Alle Felder werden bentigt.',
     24 => 'Beitrag gespeichert',
-    25 => 'Ihr %s-Beitrag wurde gespeichert.',
+    25 => 'Der %s-Beitrag wurde gespeichert.',
     26 => 'Speed Limit',
     27 => 'Username',
     28 => 'Kategorie',
@@ -719,7 +719,7 @@ $LANG21 = array(
     49 => ' (keine Leerzeichen, muss eindeutig sein)',
     50 => '',
     51 => '(mit http://)',
-    52 => 'Wenn das Feld leer ist, wird kein Hilfe-Symbol zu diesem Block angezeigt.',
+    52 => 'Wenn das Feld leer ist, wird kein Hilfesymbol zu diesem Block angezeigt.',
     53 => 'Aktiv',
     54 => 'Speichern',
     55 => 'Abbruch',
@@ -735,7 +735,7 @@ $LANG21 = array(
     65 => 'Reihenfolge',
     66 => 'Autotags',
     67 => 'Ankreuzen, um Autotags zu interpretieren',
-    68 => 'The Newsfeed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
+    68 => 'Der Newsfeed fr diesen Portalblock ist zu lang, um angezeigt zu werden. Bitte eine maximale Anzahl Artikel angeben, die fr den Block importiert werden soll. Dieses entweder im Blockeditor einstellen oder in der allgemeinen Voreinstelung in der Geeklog Konfiguration.'
 );
 
 ###############################################################################
@@ -765,7 +765,7 @@ $LANG24 = array(
     21 => 'Senden',
     22 => 'Artikelliste',
     23 => 'Auf das ndern-Symbol klicken, um einen Artikel zu ndern oder zu lschen. Um einen Artikel anzusehen, auf dessen Titel klicken. Auf Neu anlegen (s.o.) klicken, um einen neuen Artikel zu schreiben.',
-    24 => 'Diese ID wird bereits fr einen anderen Artikel benutzt. Bitte whlen Sie eine andere ID.',
+    24 => 'Diese ID wird bereits fr einen anderen Artikel benutzt. Bitte eine andere ID whlen.',
     25 => 'Fehler beim Speichern des Artikels',
     26 => 'Artikelvorschau',
     27 => '<p>Wenn Sie [unscaledX] statt [imageX] verwenden, wird das Bild in Originalgre eingebunden.',
@@ -804,7 +804,7 @@ $LANG24 = array(
     60 => '',
     61 => 'automatisch archivieren',
     62 => 'automatisch lschen',
-    63 => 'Kommentarmglichkeit zeitgesteuert ausschalten',
+    63 => 'Kommentare abschalten',
     64 => '',
     65 => '',
     66 => '',
@@ -818,8 +818,8 @@ $LANG24 = array(
     74 => 'Extra II Symbolleiste',
     75 => 'Alle Symbole',
     76 => 'Verffentlichung',
-    77 => 'JavaScript mu fr den WYSIWYG-Editor an sein. Der WYSIWYG-Editor kann im Configuration Admin Panel ausgeschaltet werden.',
-    78 => 'Klicken Sie <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">hier</a>, um den  Default-Editor zu verwenden',
+    77 => 'JavaScript mu fr den WYSIWYG-Editor an sein. Der WYSIWYG-Editor kann in der Geeklog Konfiguration ausgeschaltet werden.',
+    78 => 'Klicken Sie <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">hier</a>, um den Standard-Editor zu verwenden',
     79 => 'Vorschau',
     80 => 'Editor',
     81 => 'Verffentlichung',
@@ -829,7 +829,10 @@ $LANG24 = array(
     85 => 'Alles anzeigen',
     86 => 'WYSIWYG-Editor',
     87 => 'Artikel-Statistik',
-    88 => 'Format im Wiki-Stil '
+    88 => 'Format im Wiki-Stil',
+    89 => 'Metatag Description',
+    90 => 'Metatag Keywords',
+    91 => 'Sie knnen aber jederzeit auf "Vorschau" klicken, um diese Zeit zu verlngern.'
 );
 
 ###############################################################################
@@ -853,18 +856,19 @@ $LANG27 = array(
     15 => 'alphabetisch',
     16 => 'Default:',
     17 => 'Neue Kategorie',
-    18 => 'Kommandozentrale',
+    18 => 'Schaltzentrale',
     19 => 'Speichern',
     20 => 'Abbruch',
     21 => 'Lschen',
     22 => 'Default',
-    23 => 'Zur Default-Kategorie fr neue Artikel machen',
+    23 => 'Zur voreingestellten Kategorie fr neue Artikel machen',
     24 => '(*)',
     25 => 'Archiv-Kategorie',
     26 => 'Zur Archiv-Kategorie machen (nur fr eine Kategorie mglich)',
     27 => 'oder ein Symbol hochladen',
     28 => 'maximal',
-    29 => 'Fehler beim Datei-Upload'
+    29 => 'Fehler beim Datei-Upload',
+    30 => 'Artikel i.d. Kategorie'
 );
 
 ###############################################################################
@@ -931,9 +935,9 @@ $LANG28 = array(
     58 => 'Einmal-User',
     59 => 'Alte User',
     60 => 'User, angemeldet vor mehr als ',
-    61 => ' Monaten, aber nie eingelogged.',
+    61 => ' Monaten, aber nie eingeloggt.',
     62 => 'User, angemeldet vor mehr als  ',
-    63 => ' Monaten, dann nur einmalig innerhalb 24 h eingelogged.',
+    63 => ' Monaten, dann nur einmalig innerhalb 24 h eingeloggt.',
     64 => 'Normale User, die einfach die Site nicht mehr besucht haben seit ',
     65 => ' Monaten.',
     66 => 'Liste aktualisieren',
@@ -952,8 +956,8 @@ $LANG28 = array(
     79 => 'Keine User ausgewhlt fr Erinnerung',
     80 => 'Erinnerung erfolgreich verschickt',
     81 => 'Erinnerung, um den Account zu verifizieren fr %s',
-    82 => "Ihr Account auf der Seite {$_CONF['site_name']} wurde nicht benutzt seit %s und wird innerhalb  30 .",
-    83 => "Ihr Account auf der Seite {$_CONF['site_name']} wurde seit der Einrichtung nicht benutzt \und wird gelscht, wenn Sie nicht in Krze einloggen.",
+    82 => "Ihr Account auf der Seite {$_CONF['site_name']} wurde nicht benutzt seit %s und wird deaktiviert, wenn Sie nicht innerhalb 30 Tagen einloggen.",
+    83 => "Ihr Account auf der Seite {$_CONF['site_name']} wurde seit der Einrichtung nicht benutzt und wird gelscht, wenn Sie nicht in Krze einloggen.",
     84 => "Ihr Einlogname ist: %s  auf der Site: {$_CONF['site_url']}",
     85 => 'Wenn Sie Ihr Passwort vergessen haben, benutzen Sie folgenden Link: %s',
     86 => 'Enthalten',
@@ -977,16 +981,16 @@ $LANG29 = array(
     16 => 'Username',
     17 => 'Name',
     18 => 'E-Mail',
-    34 => 'Kommandozentrale',
+    34 => 'Schaltzentrale',
     35 => 'Beitrge: Artikel',
-    36 => 'Parent or Kommentar',
+    36 => 'Bezug oder Kommentar',
     37 => '',
     38 => 'Abschicken',
     39 => 'Derzeit gibt es keine Beitrge zu moderieren.',
     40 => 'Neue User',
-    41 => 'Eingereichte Kommentare',
-    42 => 'User Name',
-    43 => 'Kommentare automatisch verffentlichen?'
+    41 => 'Beitrge: Kommentare',
+    42 => 'Username',
+    43 => 'Moderation aufheben?'
 );
 
 ###############################################################################
@@ -994,10 +998,10 @@ $LANG29 = array(
 
 $LANG31 = array(
     1 => "{$_CONF['site_name']} Mail Utility",
-    2 => 'Von',
-    3 => 'Reply-to',
+    2 => 'Von (Name)',
+    3 => 'Von (E-Mail)',
     4 => 'Betreff',
-    5 => 'Text',
+    5 => 'Nachricht',
     6 => 'Senden',
     7 => 'Alle User',
     8 => 'Admin',
@@ -1033,13 +1037,13 @@ $LANG32 = array(
     6 => 'Warnung: Plugin schon installiert!',
     7 => 'Das Plugin, das Sie installieren wollen, ist schon vorhanden. Bitte lschen Sie es, bevor Sie noch einmal versuchen, es zu installieren',
     8 => 'Plugin-Kompatibilittstest fehlgeschlagen',
-    9 => 'Dieses Plugin bentigt eine neuere Version von Geeklog. Abhilfe schafft ein Update von <a href="http://www.geeklog.net/">Geeklog</a> oder evtl. eine andere Version dieses Plugins.',
+    9 => 'Dieses Plugin bentigt eine neuere Version von Geeklog. Abhilfe schafft ein Update von <a href="http://www.geeklog.net/">Geeklog</a>.',
     10 => '<br' . XHTML . '><b>Es sind derzeit keine Plugins installiert.</b><br' . XHTML . '><br' . XHTML . '>',
     11 => 'Um ein Plugin zu ndern oder zu lschen, auf das ndern-Symbol klicken. Es werden dann auch weitere Details, inkl. der Homepage des Plugins, angezeigt. Wenn in der Liste (s.u.) zwei Versionsnummern fr ein Plugin angezeigt werden, bedeutet das, dass fr das Plugin noch ein Update durchgefhrt werden muss. Um ein Plugin zu installieren oder aktualisieren bitte auch immer dessen Dokumentation lesen.',
     12 => '(kein Name angegeben)',
     13 => 'Plugin-Editor',
     14 => 'Neues Plugin',
-    15 => 'Kommandozentrale',
+    15 => 'Schaltzentrale',
     16 => 'Name des Plugins',
     17 => 'Plugin-Version',
     18 => 'Geeklog-Version',
@@ -1055,7 +1059,7 @@ $LANG32 = array(
     28 => 'Plugin-Version',
     29 => 'Geeklog-Version',
     30 => 'Plugin lschen?',
-    31 => 'Sind Sie sicher, dass Sie dieses Plugin lschen wollen? Dies wird alle Daten und Datenstrukturen lschen, die dieses Plugin benutzt. Wenn Sie sicher sind, dann klicken Sie jetzt bitte noch einmal auf Lschen.',
+    31 => 'Soll das Plugin wirklich gelscht werden? Dies wird alle Daten und Datenstrukturen lschen, die dieses Plugin benutzt. Wenn ja, dann jetzt bitte noch einmal auf Lschen klicken.',
     32 => '<p><b>Fehler: Ungltiges Format fr Autolink.</b></p>',
     33 => 'Code-Version',
     34 => 'Aktualisieren',
@@ -1063,19 +1067,20 @@ $LANG32 = array(
     36 => 'Code',
     37 => 'Aktuell',
     38 => 'Bitte aktualisieren!',
-    39 => 'Upload a plugin',
-    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
-    41 => 'Upload',
-    99 => 'An unknown error occured',
+    39 => 'Ein Plugin hochladen',
+    40 => 'Ein Plugin-Archiv (.tar.gz, .tgz, .zip) kann hier direkt hochgeladen werden:',
+    41 => 'Hochladen',
+    42 => 'Fr Update klicken',
+    99 => 'Ein unbekannter Fehler ist aufgetreten',
     100 => 'Ok.',
-    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
-    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
+    101 => 'Die Datei zum Hochladen ist grer als die Einstellung upload_max_filesize auf dem Webspace erlaubt.',
+    102 => 'Die Datei zum Hochladen ist grer als die Einstellung MAX_FILE_SIZE, die im HTML-Formular angegeben wurde.',
     103 => 'The uploaded file was only partially uploaded.',
-    104 => 'No file was uploaded.',
-    105 => '(undefined error)',
-    106 => 'Missing a temporary folder.',
-    107 => 'Failed to write file to disk.',
-    108 => 'File upload stopped by extension.'
+    104 => 'Es ist keine Datei hochgeladen worden.',
+    105 => '(undefinierter Fehler)',
+    106 => 'Es fehlt ein temporres Unterverzeichnis.',
+    107 => 'Datei konnte nicht geschrieben werden.',
+    108 => 'Hochladen wurde gestoppt wegen der Dateiendung.'
 );
 
 ###############################################################################
@@ -1088,7 +1093,7 @@ $LANG33 = array(
     4 => 'Abbruch',
     10 => 'Newsfeed',
     11 => 'Neuer Newsfeed',
-    12 => 'Kommandozentrale',
+    12 => 'Schaltzentrale',
     13 => 'Um einen Newsfeed zu ndern oder zu lschen, auf das ndern-Symbol (s.u.) klicken. Um einen neuen Newsfeed anzulegen, auf Neu anlegen (s.o.) klicken.',
     14 => 'Titel',
     15 => 'Art',
@@ -1127,10 +1132,10 @@ $LANG33 = array(
     48 => 'ndern',
     49 => 'Newsfeed-Logo',
     50 => "Relativ zur URL dieser Site ({$_CONF['site_url']})",
-    51 => 'Der gewhlte Dateiname wird bereits von einem anderen Newsfeed verwendet. Bitte whlen Sie einen anderen.',
+    51 => 'Der gewhlte Dateiname wird bereits von einem anderen Newsfeed verwendet. Bitte einen anderen Namen whlen.',
     52 => 'Fehler: Dateiname existiert schon',
     53 => 'Alle auf der Startseite',
-    54 => 'Bitte whlen Sie die Art des Newsfeeds aus.',
+    54 => 'Bitte die Art des Newsfeeds auswhlen.',
     55 => 'Artikel'
 );
 
@@ -1139,21 +1144,21 @@ $LANG33 = array(
 
 $MESSAGE = array(
     1 => "Ihr Passwort sollte in Krze per E-Mail bei Ihnen eintreffen. Bitte beachten Sie die Hinweise in der E-Mail. Danke, dass Sie sich bei {$_CONF['site_name']} angemeldet haben.",
-    2 => "Danke fr Ihren Beitrag zu {$_CONF['site_name']}. Ihr Artikel wurde an unser Team weitergeleitet. Wenn er akzeptiert wird, wird er bald auf dieser Website fr alle Besucher zu lesen sein.",
+    2 => "Danke fr Ihren Beitrag zu {$_CONF['site_name']}. Der Artikel wurde an unser Team weitergeleitet. Wenn er akzeptiert wird, wird er bald auf dieser Website fr alle Besucher zu lesen sein.",
     3 => '',
     4 => '',
-    5 => 'Ihr Userprofil wurde gespeichert.',
-    6 => 'Ihre Einstellungen wurden gespeichert.',
-    7 => 'Ihre Kommentar-Einstellungen wurden gespeichert.',
+    5 => 'Userprofil wurde gespeichert.',
+    6 => 'Einstellungen wurden gespeichert.',
+    7 => 'Kommentar-Einstellungen wurden gespeichert.',
     8 => 'Abmeldung erfolgt. Sie sind jetzt nicht mehr angemeldet.',
-    9 => 'Ihr Artikel wurde gespeichert.',
-    10 => 'Der Artikel wurde gelscht.',
-    11 => 'Ihr Block wurde gespeichert.',
+    9 => 'Artikel wurde gespeichert.',
+    10 => 'Artikel wurde gelscht.',
+    11 => 'Block wurde gespeichert.',
     12 => 'Der Block wurde gelscht.',
-    13 => 'Ihre Kategorie wurde gespeichert.',
+    13 => 'Kategorie wurde gespeichert.',
     14 => 'Die Kategorie und alle zugehrigen Artikel wurden gelscht.',
-    15 => 'Der Kommentar wurde zur Moderation eingereicht. Er wird verffentlicht, wenn ein Moderator zustimmt.',
-    16 => 'Abonnement wurde gelscht. Es gibt nicht lnger Benachrichtigungen bei Antworten.',
+    15 => 'Der Kommentar wurde gespeichert, muss aber noch von einem Moderator freigegeben werden.',
+    16 => 'Abonnement wurde gelscht. Sie werden nicht lnger ber Antworten benachrichtigt.',
     17 => '',
     18 => '',
     19 => '',
@@ -1186,7 +1191,7 @@ $MESSAGE = array(
     46 => '',
     47 => 'Diese Funktion luft nur unter *nix.  Wenn *nix als Betriebssystem luft, dann wurde der Cache erfolgreich gelscht. Wenn Windows als Betriebssystem luft, bitte nach den Dateien adodb_*.php suchen und diese manuell entfernen.',
     48 => "Danke, dass Sie sich bei {$_CONF['site_name']} angemeldet haben. Ihr Aufnahmeantrag wird von unserem Team geprft. Sobald er akzeptiert wird, werden Sie ein Passwort per E-Mail erhalten.",
-    49 => 'Ihre Gruppe wurde gespeichert.',
+    49 => 'Die Gruppe wurde gespeichert.',
     50 => 'Die Gruppe wurde gelscht.',
     51 => 'Dieser Username ist schon vergeben. Bitte whlen Sie einen anderen.',
     52 => 'Die angegebene E-Mail-Adresse scheint nicht gltig zu sein.',
@@ -1201,7 +1206,7 @@ $MESSAGE = array(
     61 => 'Plugin %s: Unbekannter Text-Platzhalter',
     62 => 'Der Trackback-Kommentar wurde gelscht.',
     63 => 'Beim Lschen des Trackback-Kommentars trat ein Fehler auf.',
-    64 => 'Ihr Trackback-Kommentar wurde erfolgreich verschickt.',
+    64 => 'Trackback-Kommentar wurde erfolgreich verschickt.',
     65 => 'Das Weblog-Verzeichnis wurde gespeichert.',
     66 => 'Das Weblog-Verzeichnis wurde gelscht.',
     67 => 'Das neue Passwort stimmt nicht mit dem Besttigungs-Passwort berein!',
@@ -1214,7 +1219,7 @@ $MESSAGE = array(
     74 => 'Der Pingback wurde erfolgreich verschickt.',
     75 => 'Trackbacks mssen als POST-Request verschickt werden.',
     76 => 'Wollen Sie diesen Eintrag wirklich lschen?',
-    77 => 'HINWEIS:<br' . XHTML . '>Sie haben UTF-8 als Default-Zeichensatz angegeben. Ihr Webserver untersttzt jedoch kein "multibyte encoding". Installieren Sie bitte die mbstring-Erweiterung fr PHP oder benutzen Sie einen anderen Zeichensatz bzw. eine andere Sprache.',
+    77 => 'HINWEIS:<br' . XHTML . '>Sie haben UTF-8 als Standard-Zeichensatz angegeben. Ihr Webserver untersttzt jedoch kein "multibyte encoding". Installieren Sie bitte die mbstring-Erweiterung fr PHP oder benutzen Sie einen anderen Zeichensatz bzw. eine andere Sprache.',
     78 => 'Bitte sicherstellen, dass die angegebene E-Mail-Adresse in beiden Fllen die gleiche ist.',
     79 => 'Diese Funktion ist nicht mehr unter dieser URL verfgbar.',
     80 => 'Das Plugin, das diesen Newsfeed angelegt hat, ist derzeit nicht aktiviert. Dieser Newsfeed kann nicht bearbeitet werden, solange das Plugin deaktiviert ist.',
@@ -1227,7 +1232,7 @@ $MESSAGE = array(
     87 => 'OpenID-Login wurde vom User abgebrochen.',
     88 => 'Der OpenID-Server gab einen Fehler zurck.',
     89 => 'Kann OpenID-Server nicht finden bzgl. der angegebenen Identity-URL.',
-    90 => 'OpenID- Identifizierung abgebrochen.',
+    90 => 'OpenID-Identifizierung abgebrochen.',
     91 => 'You specified an invalid identity URL.',
     92 => "Bitte <a href=\"{$_CONF['site_admin_url']}/sectest.php\">die Sicherheit Ihrer Site berprfen</a> bevor Sie sie benutzen!",
     93 => 'Datenbank-Backup war erfolgreich.',
@@ -1238,9 +1243,9 @@ $MESSAGE = array(
     98 => 'Das Plugin wurde erfolgreich hochgeladen.',
     99 => 'Das Plugin existiert schon.',
     100 => 'Die hochgeladene Plugindatei ist kein GZip oder Zip-Archiv.',
-    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
-    400 => 'Not all required fields have been passed validation',
-    401 => 'Please enter Fullname'
+    101 => 'Es gibt keine Kategorien (, auf die Sie Zugriff haben). Es bedarf mindestens einer Kategorie, um Beitrge zu schreiben.',
+    400 => 'Nicht alle erforderlichen Felder konnten besttigt werden',
+    401 => 'Bitte den echten Namen eingeben'
 );
 
 ###############################################################################
@@ -1256,13 +1261,13 @@ $LANG_ACCESS = array(
     'permmsg' => 'Hinweis: Mitglieder bedeutet alle eingeloggten Mitglieder und Gast steht fr alle nicht eingeloggten Besucher.',
     'securitygroups' => 'Security-Gruppen',
     'editrootmsg' => "Obwohl Sie User-Administrator sind, knnen Sie die Informationen von Usern in der Root-Gruppe nicht ndern, ohne selbst Mitglied der Root-Gruppe zu sein. Sie knnen die Informationen aller anderen User bearbeiten, nur nicht die der Mitglieder der Root-Gruppe. Beachten Sie bitte, dass alle derartigen Versuche protokolliert werden. <a href=\"{$_CONF['site_admin_url']}/user.php\">Zurck zur User-Admin-Seite</a>.",
-    'securitygroupsmsg' => 'Mit den Checkboxen knnen Sie festlegen, zu welchen Gruppen dieser User gehrt.',
+    'securitygroupsmsg' => 'Mit den Anklickkstchen kann man festlegen, zu welchen Gruppen dieser User gehrt.',
     'groupeditor' => 'Gruppen-Editor',
     'description' => 'Beschreibung',
     'name' => 'Name',
     'rights' => 'Rechte',
     'missingfields' => 'Fehlende Angaben',
-    'missingfieldsmsg' => ' Sie mssen den Namen und eine Beschreibung fr die Gruppe angeben.',
+    'missingfieldsmsg' => ' Bite einen Namen und eine Beschreibung fr die Gruppe angeben.',
     'groupmanager' => 'Gruppen-Manager',
     'newgroupmsg' => 'Um eine Gruppe zu ndern oder zu lschen, auf das ndern-Symbol klicken. Neu anlegen (s.o.) legt eine neue Gruppe an. Hinweis: Core-Gruppen knnen nicht gelscht werden, da sie vom System bentigt werden.',
     'groupname' => 'Gruppen-Name',
@@ -1285,7 +1290,7 @@ $LANG_ACCESS = array(
     'nogroupsforcoregroup' => 'Diese Gruppe gehrt zu keiner anderen Gruppe.',
     'grouphasnorights' => 'Diese Gruppe hat keine Rechte fr die Administration der Website.',
     'newgroup' => 'Neue Gruppe',
-    'adminhome' => 'Kommandozentrale',
+    'adminhome' => 'Schaltzentrale',
     'save' => 'Speichern',
     'cancel' => 'Abbruch',
     'delete' => 'Lschen',
@@ -1318,7 +1323,7 @@ $LANG_DB_BACKUP = array(
     'last_ten_backups' => 'Die 10 letzten Backups',
     'do_backup' => 'Backup anlegen',
     'backup_successful' => 'Backup der Datenbank war erfolgreich.',
-    'db_explanation' => 'Um ein neues Backup Ihrer Datenbank anzulegen, bitte auf Neu anlegen (s.o.) klicken. Ein Klick auf einen Dateinamen ldt das Backup herunter.',
+    'db_explanation' => 'Um ein neues Backup der Datenbank anzulegen, bitte auf Neu anlegen (s.o.) klicken. Ein Klick auf einen Dateinamen ldt das Backup herunter.',
     'not_found' => "Falscher Pfad oder sicherheitsbedingte Einschrnkung oder mysqldump ist nicht ausfhrbar.<br" . XHTML . ">Bitte berprfen Sie die Einstellung <strong>mysqldump_path</strong> in der Konfiguration und ggfs. die <a href=\"http://www.php.net/manual/en/features.safe-mode.php#ini.open-basedir\">open_basedir</a>-Einstellung in PHP.<br" . XHTML . ">Aktuelle Einstellung: <var>{$_DB_mysqldump_path}</var>",
     'zero_size' => 'Backup fehlgeschlagen: Datei ist 0 Bytes gro.',
     'path_not_found' => "{$_CONF['backup_path']} existiert nicht oder ist kein Verzeichnis.",
@@ -1327,7 +1332,26 @@ $LANG_DB_BACKUP = array(
     'size' => 'Gre',
     'bytes' => 'Bytes',
     'total_number' => 'Gesamtanzahl Backups: %d',
-    'download' => 'Anklicken, um diese Datei runterzuladen'
+    'download' => 'Anklicken, um diese Datei runterzuladen',
+    'new_backup' => 'Neues Backup',
+    'delete_failure' => 'Eins oder mehrere Backups konnten nicht gelscht werden.',
+    'delete_success' => 'Backupdateien erfolgreich gelscht.',
+    'convert_menu' => 'Convert to InnoDB',
+    'convert_title' => 'Convert to InnoDB tables',
+    'convert_button' => 'Convert',
+    'sorry_no_innodb' => 'Sorry, die MySQL-Version auf dem Server untersttzt kein InnoDB.',
+    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
+    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
+    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
+    'innodb_success' => 'Successfully converted tables to InnoDB.',
+    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
+    'optimize_menu' => 'Tabellen optimieren',
+    'optimize_title' => 'Tabellen Optimieren',
+    'optimize_button' => 'Optimieren',
+    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
+    'last_optimization' => 'Letzte Optimierung',
+    'optimization_patience' => 'Hinweis: Die Optimierung kann etwas Zeit in Anspruch nehmen. Bitte etwas Geduld mitbringen.',
+    'optimize_success' => 'Tabellen wurden erfolgreich optimiert.'
 );
 
 ###############################################################################
@@ -1360,7 +1384,7 @@ $LANG_404 = array(
 
 $LANG_LOGIN = array(
     1 => 'Anmeldung erforderlich',
-    2 => 'Sorry, aber um auf diesen Bereich zugreifen zu knnen, mssen Sie als Benutzer registriert ein.',
+    2 => 'Sorry, aber um auf diesen Bereich zugreifen zu knnen, muss man als Benutzer registriert sein.',
     3 => 'Anmelden',
     4 => 'Neuer User'
 );
@@ -1373,7 +1397,7 @@ $LANG_TRB = array(
     'from' => 'von',
     'tracked_on' => 'Empfangen am',
     'read_more' => '[mehr]',
-    'intro_text' => 'Auf anderen Sites wurde folgendes ber \'%s\' geschrieben:',
+    'intro_text' => 'Andere haben folgendes ber \'%s\' geschrieben:',
     'no_comments' => 'Keine Trackback-Kommentare fr diesen Eintrag.',
     'this_trackback_url' => 'Trackback-URL fr diesen Eintrag:',
     'num_comments' => '%d Trackback-Kommentare',
@@ -1393,7 +1417,7 @@ $LANG_TRB = array(
     'url_missing' => 'Keine URL fr den Eintrag',
     'url_required' => 'Es muss mindestens die URL fr den Eintrag angegeben werden.',
     'target_missing' => 'Keine Trackback-URL',
-    'target_required' => 'Bitte geben Sie die Trackback-URL ein.',
+    'target_required' => 'Bitte die Trackback-URL eingeben.',
     'error_socket' => 'Socket konnte nicht geffnet werden.',
     'error_response' => 'Antwort nicht verstanden.',
     'error_unspecified' => 'Fehler nicht nher spezifiziert.',
@@ -1467,25 +1491,25 @@ $LANG_DIR = array(
 # admin/sectest.php
 
 $LANG_SECTEST = array(
-    'sectest' => 'Geeklog Security Check',
-    'results' => 'Results of the Security Check',
-    'okay' => 'Everything seems to be in order.',
-    'please_fix' => 'Please fix the above issues before using your site!',
-    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
-    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
-    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
-    'installation' => 'installation instructions',
-    'directory' => 'directory',
-    'failed_bak' => 'Failed to create a temporary file in your data directory. Check your directory permissions!',
-    'fix_it' => 'This is a security risk and should be fixed!',
-    'reachable' => 'Your %s is reachable from the web.',
-    'not_reachable' => 'Good! Your %s is not reachable from the web.',
-    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
-    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
-    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
-    'inst_removed' => 'Good! You seem to have removed the install directory already.',
-    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
-    'password_okay' => 'Good! You seem to have changed the default account password already.'
+    'sectest' => 'Geeklog Sicherheits-Check',
+    'results' => 'Ergebnis des Sicherheits-Checks',
+    'okay' => 'Es scheint alles in Ordnung zu sein.',
+    'please_fix' => 'Bitte die o.g. Fehler beheben, um den Webauftritt endgltig zu nutzen!',
+    'please_note' => 'Kein Internetauftritt ist 100% sicher. Der Test kann nur bekannte, offensichtliche Probleme untersuchen.',
+    'stay_informed' => 'Um ber Geeklog-Updates und Sicherheitsprobleme informiert zu bleiben, sollte man die  (low-traffic) %s Mailingliste abonnieren und ggf. mit der %s -Option im Adminmen nach verfgbaren Updates schauen.',
+    'public_html' => '"public_html" sollte nie Teil der URL der Website sein. Bitte den Teil der %s noch einmal lesen und die Installation entsprechend ndern.',
+    'installation' => 'Installationsanleitung',
+    'directory' => 'Verzeichnis',
+    'failed_tmp' => 'Konnte temporre Datei nicht im %s -Verzeichnis erstellen. Bitte die Rechte berprfen!',
+    'fix_it' => 'Dies ist ein Sicherheitsrisiko und sollte behoben werden!',
+    'reachable' => 'Auf das %s kann ber das Internet zugegriffen werden.',
+    'not_reachable' => 'Prima! Auf das %s kann ber das Internet nicht zugegriffen werden.',
+    'not_sure' => 'Es kommt ein HTTP-Ergebniscode %s beim Versuch, das %s zu testen. Es ist nicht klar, was das bedeutet ...',
+    'remove_inst' => 'Das Installations-Verzeichnis %s sollte entfernt werden, sobald der Webauftritt fehlerfrei luft.',
+    'remove_inst2' => 'Es beizubehalten wrde Angreifern die Mglichkeit geben, den Webauftritt zu zerstren, den Auftritt zu kapern oder wichtige Informationen zu erlangen.',
+    'inst_removed' => 'Prima! Das Installations-Verzeichnis ist schon entfernt worden.',
+    'fix_password' => 'Das <strong>Standardkennwort</strong> "password" des %s Root-Admin-Accounts wurde noch nicht gendert.',
+    'password_okay' => 'Prima! Das Standardkennwort ist schon ausgetauscht worden.'
 );
 
 ###############################################################################
@@ -1556,7 +1580,7 @@ $LANG_ADMIN = array(
     'submit' => 'Abschicken',
     'edit' => 'ndern',
     'edit_adv' => 'Erw. Editor',
-    'admin_home' => 'Kommandozentrale',
+    'admin_home' => 'Schaltzentrale',
     'create_new' => 'Neu anlegen',
     'create_new_adv' => 'Neu anlegen (Erw.)',
     'enabled' => 'Funktion aktivieren',
@@ -1576,7 +1600,11 @@ $LANG_ADMIN = array(
     'addchild' => 'Add child',
     'list' => 'auflisten',
     'list_all' => 'Alle auflisten',
-    'na' => 'N/A'
+    'meta_description' => 'Metatag Description',
+    'meta_keywords' => 'Metatag Keywords',
+    'na' => 'n/v',
+    'token_expiry' => 'Achtung, zeitgesteuerte Sicherheitsfunktion (Security-Token). Nach %s lsst sich diese Seite nicht mehr speichern. nderungen gehen verloren.'
+
 );
 
 # Localisation of the texts for the various drop-down menus that are actually
@@ -1744,7 +1772,7 @@ $LANG_confignames['Core'] = array(
     'postmode' => 'Default Post Mode',
     'speedlimit' => 'Post Speedlimit',
     'skip_preview' => 'Vorschau berspringen in Posts',
-    'advanced_editor' => 'WYSIWYG Editor?',
+    'advanced_editor' => 'WYSIWYG-Editor?',
     'wikitext_editor' => 'Wikitext Editor?',
     'cron_schedule_interval' => 'Zeitabstand fr Cronjobs',
     'sortmethod' => 'Kategorien sortieren',
@@ -1848,12 +1876,16 @@ $LANG_confignames['Core'] = array(
     'censorlist' => 'Liste zensierter Wrter',
     'ip_lookup' => 'IP Lookup',
     'url_rewrite' => 'URL-Rewrite einschalten',
+    'meta_tags' => 'Meta Tags',
+    'meta_description' => 'Default Meta Description',
+    'meta_keywords' => 'Default Meta Keywords',
     'default_permissions_block' => 'Grundeinstellung Blockrechte',
     'default_permissions_story' => 'Grundeinstellung Artikelrechte',
     'default_permissions_topic' => 'Grundeinstellung Kategorierechte',
     'atom_max_stories' => 'Max. Artikel im Webservices-Feed',
     'disable_webservices' => 'Webservices ausschalten?',
     'restrict_webservices' => 'Webservices beschrnken?',
+    'article_comment_close_enabled' => 'Automatisch Kommentarmglichkeit abschalten (Grundeinstellung)',
     'article_comment_close_days' => 'Tage nach denen Kommentare uneditierbar werden (hier nur Grundeinstellung)',
     'comment_close_rec_stories' => 'Anzahl letzter Artikel, die kommentierbar sein sollen',
     'allow_reply_notifications' => 'Benachrichtigung auf Kommentare erlauben?',
@@ -1873,7 +1905,7 @@ $LANG_configsubgroups['Core'] = array(
     'sg_theme' => 'Theme',
     'sg_blocks' => 'Blcke',
     'sg_users' => 'User und Beitrge',
-    'sg_images' => 'Images',
+    'sg_images' => 'Bilder',
     'sg_locale' => 'Sprache und Lokalisierung',
     'sg_misc' => 'Vermischtes'
 );
@@ -1945,7 +1977,8 @@ $LANG_configselects['Core'] = array(
     19 => array('Google' => 'google', 'Tabelle' => 'table'),
     20 => array('Exakter Ausdruck' => 'phrase', 'Alle Worte' => 'all', 'Eines der Worte' => 'any'),
     21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
-    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => '')
+    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
+    23 => array('Deaktiviert' => 0, 'Aktiviert' => 1, 'Aktiviert (Default nur auf der Startseite)' => 2)
 );
 
 ?>
