@@ -37,30 +37,6 @@
 require_once '../../lib-common.php';
 require_once 'lib-install.php';
 
-$pi_preinstall = array(
-    'calendar'     => TRUE,
-    'links'        => TRUE,
-    'polls'        => TRUE,
-    'spamx'        => TRUE,
-    'staticpages'  => TRUE,
-    'xmlsitemap'   => TRUE,
-    'autotags'     => FALSE,
-    'calendarjp'   => FALSE,
-    'captcha'      => FALSE,
-    'custommenu'   => FALSE,
-    'dataproxy'    => FALSE,
-    'dbman'        => FALSE,
-    'filemgmt'     => FALSE,
-    'forum'        => FALSE,
-    'japanize'     => FALSE,
-    'mycaljp'      => FALSE,
-    'nmoxqrblock'  => FALSE,
-    'nmoxtopicown' => FALSE,
-    'sitemap'      => FALSE,
-    'themedit'     => FALSE,
-    'tkgmaps'      => FALSE
-);
-
 // Set some vars
 $html_path          = INST_getHtmlPath();
 $siteconfig_path    = '../../siteconfig.php';
@@ -98,8 +74,8 @@ $display = INST_getHeader($LANG_PLUGINS[2] . ' 3 - ' . $LANG_PLUGINS[1]); // Gra
 if (INST_phpOutOfDate()) {
 
     // If their version of PHP is not supported, print an error:
-    $display .= '<h1>' . $LANG_INSTALL[4] . '</h1>' . LB;
-    $display .= '<p>' . $LANG_INSTALL[5] . $phpv[0] . '.' . $phpv[1] . '.' . (int) $phpv[2] . $LANG_INSTALL[6] . '</p>' . LB;
+    $display .= '<h1>' . sprintf($LANG_INSTALL[4], SUPPORTED_PHP_VER) . '</h1>' . LB;
+    $display .= '<p>' . sprintf($LANG_INSTALL[5], SUPPORTED_PHP_VER) . $phpv[0] . '.' . $phpv[1] . '.' . (int) $phpv[2] . $LANG_INSTALL[6] . '</p>' . LB;
 
 } else {
 
@@ -386,7 +362,8 @@ if (INST_phpOutOfDate()) {
                             $pi_version      = $info['pi_version'];
                             $gl_version      = $info['pi_gl_version'];
                             $pi_url          = $info['pi_homepage'];
-                            $pi_checked      = ($pi_preinstall[$plugin]) ? ' checked="checked"' : '';
+                            require_once 'disable-plugins.php';
+                            $pi_checked      = ($_GEEKLOGJP_pi_preinstall[$plugin]) ? ' checked="checked"' : '';
                         }
 
                         // If the plugin has been installed to the admin directory
