@@ -49,8 +49,8 @@ $LANG_INSTALL = array(
     1 => 'תמיכת התקנה',
     2 => 'The Ultimate Weblog System',
     3 => 'התקנת Geeklog',
-    4 => 'דרוש PHP 4.3.0',
-    5 => 'מצטערים, אבל Geeklog דורש לפחות PHP 4.3.0 בשביל לרוץ (לכם יש גירסה ',
+    4 => 'דרוש PHP %s',
+    5 => 'מצטערים, אבל Geeklog דורש לפחות PHP %s בשביל לרוץ (לכם יש גירסה ',
     6 => '). אנא <a href="http://www.php.net/downloads.php">שדרגו את גירסת ה-PHP שלכם</a> או בקשו ממארחי השרת שלכם לעשות זאת בשבילכם.',
     7 => 'לא אותרו הקבצים של Geeklog',
     8 => 'ההתקנה לא הצליחה לאתר את הקבצים החשובים של Geeklog. זה כנראה מפני שהיזזתם אותם ממיקום ברירת המחדל שלהם. אנא ציינו את הנתיבים לקבצים ולספריות להלן:',
@@ -96,8 +96,8 @@ $LANG_INSTALL = array(
     48 => 'כתובת האימייל של האתר',
     49 => 'כתובת האימייל של No-Reply',
     50 => 'התקנה',
-    51 => 'נדרש MySQL 3.23.2 או יותר חדש',
-    52 => 'מצטערים, אך Geeklog דורש לפחות MySQL 3.23.2 כדי לרוץ (לכם יש גירסה ',
+    51 => 'נדרש MySQL %s או יותר חדש',
+    52 => 'מצטערים, אך Geeklog דורש לפחות MySQL %s כדי לרוץ (לכם יש גירסה ',
     53 => '). אנא <a href="http://dev.mysql.com/downloads/mysql/">שדרגו את גירסת ה-MySQL שלכם</a> או בקשו ממארחי השרת שלכם לעשות זאת בשבילכם.',
     54 => 'מידע מאגר המידע אינו נכון',
     55 => 'מצטערים, אך מידע מאגר המידע שציינתם נראה שגוי. אנא חיזרו ונסו שוב.',
@@ -211,7 +211,7 @@ $LANG_MIGRATE = array(
     22 => 'כבר קיים. האם תרצו להחליפו?',
     23 => 'כן',
     24 => 'לא',
-    25 => 'גרסת ה-Geeklog שבחרתם שתהיה נדידה ממנה היא ישנה מדי.',
+    25 => '',
     26 => 'הערת נדידה: ',
     27 => 'ה-"',
     28 => '" plugin חסר ונוטרל. תוכלו להתקינו ולהפעילו מחדש בכל זמן מאיזור הניהול.',
@@ -226,7 +226,7 @@ $LANG_MIGRATE = array(
     37 => 'הנדידה הושלמה',
     38 => 'תהליך הנדידה הושלם. עם זאת, סקריפט ההתקנה מצא את הדברים הבאים:',
     39 => 'נכשלה הגדרת נתיב PEAR include. מצטערים, אין דרך לטפל בגיבויי מאגר מידע מכווצים בלי PEAR.',
-    40 => "הארכיון '%s' לא נראה שמכיל קבצי SQL.",
+    40 => 'הארכיון \'%s\' לא נראה שמכיל קבצי SQL.',
     41 => 'שגיאה בהוצאת גיבוי מאגר המידע \'%s\' מתוך קובץ הגיבוי המכווץ.',
     42 => 'קובץ הגיבוי \'%s\' פשוט נעלם ...',
     43 => 'היבוא בוטל. הקובץ  \'%s\' לא נראה כמו SQL dump.',
@@ -234,7 +234,8 @@ $LANG_MIGRATE = array(
     45 => 'לא היה אפשר לזהות את גרסת מאגר המידע. אנא בצעו עדכון ידני.',
     46 => '',
     47 => 'שדרוג מאגר המידע מגירסה %s לגירסה %s נכשל.',
-    48 => 'אחד או יותר מה-plugins לא הצליח להתעדכן והיה אילוץ לנטרלו.'
+    48 => 'אחד או יותר מה-plugins לא הצליח להתעדכן והיה אילוץ לנטרלו.',
+    49 => 'השתמשו בתוכן מאגר המידע הנוכחי'
 );
 
 // +---------------------------------------------------------------------------+
@@ -336,7 +337,7 @@ $LANG_HELP = array(
     'site_mail' => 'זוהי הכתובת החוזרת בכל הודעות האימייל שישלחו מ-Geeklog ובמידע צרו קשר שמוצג בהזנות סינדיקציה.',
     'noreply_mail' => 'זוהי כתובת השולח של הודעות אימייל שנשלחות על ידי המערכת כשמשתמשים נרשמים וכדומה. היא צריכה להיות זהה לכתובת האימייל של האתר או להיות כתובת שלא מקבלת הודעות כדי למנוע מספאמרים להשיג את כתובת האימייל שלכם על ידי הרשמה לאתר. אם היא לא זהה לכתובת הרגילה, תהיה הודעה בהודעות שישלחו שלא מומלץ לענות להן.',
     'utf8' => 'ציינו האם להשתמש ב-UTF-8 בתור קידוד ברירת המחדל של האתר שלכם. מומלץ בעיקר להתקנות רב לשוניות.',
-    'migrate_file' => 'ביחרו את קובץ הגיבוי שברצונכם שינדוד. הוא יכול להיות קובץ קיים בספריית "backups" שלכם או שתוכלו להעלות קובץ מהמחשב שלכם.',
+    'migrate_file' => 'ביחרו את קובץ הגיבוי שברצונכם שינדוד. הוא יכול להיות קובץ קיים בספריית "backups" שלכם או שתוכלו להעלות קובץ מהמחשב שלכם. לחילופין, הנכם יכולים גם לנייד את התכנים הנוכחיים של מאגר המידע.',
     'plugin_upload' => 'ביחרו ארכיון plugin (בצורת zip, tar.gz או tgz) בשביל להעלות ולהתקין.'
 );
 
