@@ -42,8 +42,12 @@ $CUSTOM_MOBILE_CONF['gc_maxlifetime'] = 1440; //
 $CUSTOM_MOBILE_CONF['gc_probability'] = "1"; //
 $CUSTOM_MOBILE_CONF['gc_divisor'] = "10"; //
 
-/* 暫定的に mobile_3g の使用（XHTMLの使用）を抑制 */
-$CUSTOM_MOBILE_CONF['use_xhtml_for_3g'] = false; /* falseに固定 */
+// Opera,Safari,Chrome の場合は，3Gをfalseにするために，機種をnon 3Gにセットする。
+if( strpos( $_SERVER["HTTP_USER_AGENT"], "Opera") || strpos( $_SERVER["HTTP_USER_AGENT"], "Safari") || strpos( $_SERVER["HTTP_USER_AGENT"], "Chrome") ){
+    $CUSTOM_MOBILE_CONF['use_xhtml_for_3g'] = false;
+} else {
+    $CUSTOM_MOBILE_CONF['use_xhtml_for_3g'] = true;
+}
 
 $CUSTOM_MOBILE_UA = 0;
 
@@ -121,6 +125,7 @@ function _mobile_parse_ua()
             $CUSTOM_MOBILE_UA = $CUSTOM_MOBILE_UA + MOBILE_3G;
         }
     }
+
     CUSTOM_MOBILE_debug("User Agent: " . $_SERVER["HTTP_USER_AGENT"]);
     CUSTOM_MOBILE_debug("CUSTOM_MOBILE_UA: $CUSTOM_MOBILE_UA");
 }
