@@ -2,7 +2,7 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.6                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-security.php                                                          |
 // |                                                                           |
@@ -87,10 +87,8 @@ if (!defined('CSRF_TOKEN')) {
 *       be used once at the beginning of a page.  The resulting array $_GROUPS can then be
 *       used through out the page.
 *
-* @return array Array of group ID's user belongs to
-*
 * @param        int     $uid            User ID to get information for. If empty current user.
-* @return	array	Associative Array grp_name -> ug_main_grp_id
+* @return	array	Associative Array grp_name -> ug_main_grp_id of group ID's user belongs to
 *
 */
 function SEC_getUserGroups($uid='')
@@ -139,7 +137,7 @@ function SEC_getUserGroups($uid='')
             }
         }
 
-        if (sizeof ($cgroups) > 0) {
+        if (count($cgroups) > 0) {
             $glist = join(',', $cgroups);
             $result = DB_query("SELECT ug_main_grp_id,grp_name FROM {$_TABLES["group_assignments"]},{$_TABLES["groups"]}"
                     . " WHERE grp_id = ug_main_grp_id AND ug_grp_id IN ($glist)",1);
@@ -174,7 +172,7 @@ function SEC_groupIsRemoteUserAndHaveAccess($groupid, $groups)
     global $_TABLES, $_CONF;
     if(!isset($_CONF['remote_users_group_id']))
     {
-        $result = DB_Query("SELECT grp_id FROM {$_TABLES['groups']} WHERE grp_name='Remote Users'");
+        $result = DB_query("SELECT grp_id FROM {$_TABLES['groups']} WHERE grp_name='Remote Users'");
         if( $result )
         {
             $row = DB_fetchArray( $result );
@@ -221,13 +219,14 @@ function SEC_inGroup($grp_to_verify,$uid='',$cur_grp_id='')
         }
     }
 
-    if ((empty ($_USER['uid']) && ($uid == 1)) || ($uid == $_USER['uid'])) {
-        if (empty ($_GROUPS)) {
-            $_GROUPS = SEC_getUserGroups ($uid);
+    if ((empty($_USER['uid']) && ($uid == 1)) ||
+            (isset($_USER['uid']) && ($uid == $_USER['uid']))) {
+        if (empty($_GROUPS)) {
+            $_GROUPS = SEC_getUserGroups($uid);
         }
         $groups = $_GROUPS;
     } else {
-        $groups = SEC_getUserGroups ($uid);
+        $groups = SEC_getUserGroups($uid);
     }
 
     if (is_numeric($grp_to_verify)) {
@@ -472,15 +471,15 @@ function SEC_getPermissionsHTML($perm_owner,$perm_group,$perm_members,$perm_anon
 /**
 * Gets everything a user has permissions to within the system
 *
-* This is part of the Geeklog security implmentation.  This function
-* will get all the permissions the current user has call itself recursively.
+* This is part of the Geeklog security implementation.  This function
+* will get all the permissions the current user has. Calls itself recursively.
 *
-* @param        int     $grp_id     DO NOT USE (Used for reccursion) Current group function is working on
-* @uid		int	$uid        User to check, if empty current user.
-* @return       string   returns comma delimited list of features the user has access to
+* @param    int     $grp_id     DO NOT USE (Used for recursion) Current group function is working on
+* @param    int     $uid        User to check, if empty current user.
+* @return   string  returns comma delimited list of features the user has access to
 *
 */
-function SEC_getUserPermissions($grp_id='',$uid='')
+function SEC_getUserPermissions($grp_id='', $uid='')
 {
     global $_TABLES, $_USER, $_SEC_VERBOSE, $_GROUPS;
 
@@ -508,6 +507,11 @@ function SEC_getUserPermissions($grp_id='',$uid='')
         $groups = SEC_getUserGroups ($uid);
     }
 
+    if (empty($groups)) {
+        // this shouldn't happen - make a graceful exit to avoid an SQL error
+        return '';
+    }
+
     $glist = join(',', $groups);
     $result = DB_query("SELECT DISTINCT ft_name FROM {$_TABLES["access"]},{$_TABLES["features"]} "
                      . "WHERE ft_id = acc_ft_id AND acc_grp_id IN ($glist)");
@@ -575,10 +579,10 @@ function SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_ano
     }
 
     if ($_SEC_VERBOSE) {
-        COM_errorlog('perm_owner = ' . $perm_owner, 1);
-        COM_errorlog('perm_group = ' . $perm_group, 1);
-        COM_errorlog('perm_member = ' . $perm_members, 1);
-        COM_errorlog('perm_anon = ' . $perm_anon, 1);
+        COM_errorLog('perm_owner = ' . $perm_owner, 1);
+        COM_errorLog('perm_group = ' . $perm_group, 1);
+        COM_errorLog('perm_member = ' . $perm_members, 1);
+        COM_errorLog('perm_anon = ' . $perm_anon, 1);
         COM_errorLog('**** Leaving SEC_getPermissionValues ****', 1);
     }
 
@@ -594,7 +598,7 @@ function SEC_getPermissionValues($perm_owner,$perm_group,$perm_members,$perm_ano
 * to prepare the permissions to be save to the database
 *
 * @param        array       $perm_x     Array of permission values
-* @return       int         integer representation of a permission array 2 = read 3 = edit/read
+* @return       int         int representation of a permission array 2 = read 3 = edit/read
 * @see SEC_getPermissionValues
 *
 */
@@ -608,7 +612,7 @@ function SEC_getPermissionValue($perm_x)
 
     $retval = 0;
 
-    for ($i = 1; $i <= sizeof($perm_x); $i++) {
+    for ($i = 1; $i <= count($perm_x); $i++) {
         if ($_SEC_VERBOSE) {
             COM_errorLog("perm_x[$i] = " . current($perm_x), 1);
         }
@@ -667,7 +671,7 @@ function SEC_getFeatureGroup ($feature, $uid = '')
     $group = 0;
 
     $ft_id = DB_getItem ($_TABLES['features'], 'ft_id', "ft_name = '$feature'");
-    if (($ft_id > 0) && (sizeof ($ugroups) > 0)) {
+    if (($ft_id > 0) && (count($ugroups) > 0)) {
         $grouplist = implode (',', $ugroups);
         $result = DB_query ("SELECT acc_grp_id FROM {$_TABLES['access']} WHERE (acc_ft_id = $ft_id) AND (acc_grp_id IN ($grouplist)) ORDER BY acc_grp_id LIMIT 1");
         $A = DB_fetchArray ($result);
@@ -728,9 +732,10 @@ function SEC_authenticate($username, $password, &$uid)
 /**
 * Return the current user status for a user.
 *
+* NOTE:     May not return for banned/non-approved users.
+*
 * @param    int  $userid   Valid uid value.
 * @return   int            user status, 0-3
-* @note     May not return for banned/non-approved users.
 *
 */
 function SEC_checkUserStatus($userid)
@@ -888,11 +893,11 @@ function SEC_collectRemoteAuthenticationModules()
   * Rather self explanitory shortcut function
   * Is this the right place for this, Dirk?
   *
-  * @author Trinity L Bays <trinity93 AT gmail DOT com>
+  * @author Trinity L Bays, trinity93 AT gmail DOT com
   *
   * @param  string  $uid Their user id
   * @param  string  $gname The group name
-  * @return bool    status, true or false.
+  * @return boolean status, true or false.
   */
 function SEC_addUserToGroup($uid, $gname)
 {
@@ -971,7 +976,7 @@ function SEC_buildAccessSql ($clause = 'AND')
 * This function can be used by plugins during uninstall.
 *
 * @param    string  $feature_name   name of the feature, e.g. 'foo.edit'
-* @param    bool    $logging        whether to log progress in error.log
+* @param    boolean $logging        whether to log progress in error.log
 * @return   void
 *
 */
@@ -1031,7 +1036,7 @@ function SEC_getGroupDropdown ($group_id, $access)
             if ($group_id == $ug_id) {
                 $groupdd .= ' selected="selected"';
             }
-            $groupdd .= '>' . $ug_name . '</option>' . LB;
+            $groupdd .= '>' . ucwords($ug_name) . '</option>' . LB;
         }
         $groupdd .= '</select>' . LB;
     } else {
@@ -1068,7 +1073,7 @@ function SEC_encryptPassword($password)
   * added to forms and urls in the admin section as a non-cookie double-check
   * that the admin user really wanted to do that...
   *
-  * @param $ttl integer Time to live for token in seconds. Default is 20 minutes.
+  * @param $ttl int Time to live for token in seconds. Default is 20 minutes.
   *
   * @return string  Generated token, it'll be an MD5 hash (32chars)
   */
@@ -1088,26 +1093,21 @@ function SEC_createToken($ttl = 1200)
     /* Generate the token */
     $token = md5($_USER['uid'].$pageURL.uniqid (rand (), 1));
     $pageURL = addslashes($pageURL);
-    
+
     /* Destroy exired tokens: */
-    if($_DB_dbms == 'mssql') {
-        $sql = "DELETE FROM {$_TABLES['tokens']} WHERE (DATEADD(ss, ttl, created) < NOW())"
-           . " AND (ttl > 0)";
-    } else {
-        $sql = "DELETE FROM {$_TABLES['tokens']} WHERE (DATE_ADD(created, INTERVAL ttl SECOND) < NOW())"
-           . " AND (ttl > 0)";
-    }
-    DB_Query($sql);
-    
+    $sql['mssql'] = "DELETE FROM {$_TABLES['tokens']} WHERE (DATEADD(ss, ttl, created) < NOW()) AND (ttl > 0)";
+    $sql['mysql'] = "DELETE FROM {$_TABLES['tokens']} WHERE (DATE_ADD(created, INTERVAL ttl SECOND) < NOW()) AND (ttl > 0)";
+    DB_query($sql);
+
     /* Destroy tokens for this user/url combination */
     $sql = "DELETE FROM {$_TABLES['tokens']} WHERE owner_id={$_USER['uid']} AND urlfor='$pageURL'";
-    DB_Query($sql);
+    DB_query($sql);
     
     /* Create a token for this user/url combination */
     /* NOTE: TTL mapping for PageURL not yet implemented */
     $sql = "INSERT INTO {$_TABLES['tokens']} (token, created, owner_id, urlfor, ttl) "
            . "VALUES ('$token', NOW(), {$_USER['uid']}, '$pageURL', $ttl)";
-    DB_Query($sql);
+    DB_query($sql);
            
     $last_token = $token;
 
@@ -1121,7 +1121,7 @@ function SEC_createToken($ttl = 1200)
   * Checks the POST and GET data for a security token, if one exists, validates that it's for this
   * user and URL.
   *
-  * @return bool    true iff the token is valid and for this user.
+  * @return boolean     true if the token is valid and for this user.
   */
 function SEC_checkToken()
 {
@@ -1136,20 +1136,17 @@ function SEC_checkToken()
         $token = COM_applyFilter($_POST[CSRF_TOKEN]);
     }
     
-    if(trim($token) != '') {
-        if($_DB_dbms != 'mssql') {
-            $sql = "SELECT ((DATE_ADD(created, INTERVAL ttl SECOND) < NOW()) AND ttl > 0) as expired, owner_id, urlfor FROM "
-               . "{$_TABLES['tokens']} WHERE token='$token'";
-        } else {
-            $sql = "SELECT owner_id, urlfor, expired = 
+    if (trim($token) != '') {
+        $sql['mysql'] = "SELECT ((DATE_ADD(created, INTERVAL ttl SECOND) < NOW()) AND ttl > 0) as expired, owner_id, urlfor FROM {$_TABLES['tokens']} WHERE token='$token'";
+        $sql['mssql'] = "SELECT owner_id, urlfor, expired = 
                       CASE 
                          WHEN (DATEADD(s,ttl,created) < getUTCDate()) AND (ttl>0) THEN 1
                 
                          ELSE 0
                       END
                     FROM {$_TABLES['tokens']} WHERE token='$token'";
-        }
-        $tokens = DB_Query($sql);
+        $tokens = DB_query($sql);
+
         $numberOfTokens = DB_numRows($tokens);
         if($numberOfTokens != 1) {
             $return = false; // none, or multiple tokens. Both are invalid. (token is unique key...)
@@ -1171,8 +1168,7 @@ function SEC_checkToken()
             }
            
             // It's a one time token. So eat it.
-            $sql = "DELETE FROM {$_TABLES['tokens']} WHERE token='$token'";
-            DB_Query($sql);
+            DB_delete($_TABLES['tokens'], 'token', $token);
         }
     } else {
         $return = false; // no token.
@@ -1181,4 +1177,176 @@ function SEC_checkToken()
     return $return;
 }
 
+/**
+* Get a token's expiry time
+*
+* @param    string  $token  the token we're looking for
+* @return   int             UNIX timestamp of the expiry time or 0
+*
+*/
+function SEC_getTokenExpiryTime($token)
+{
+    global $_TABLES, $_USER;
+
+    $retval = 0;
+
+    if (!COM_isAnonUser()) {
+
+        $sql['mysql'] = "SELECT UNIX_TIMESTAMP(DATE_ADD(created, INTERVAL ttl SECOND)) AS expirytime FROM {$_TABLES['tokens']} WHERE (token = '$token') AND (owner_id = '{$_USER['uid']}') AND (ttl > 0)";
+        $sql['mssql'] = "SELECT UNIX_TIMESTAMP(DATEADD(ss, ttl, created)) AS expirytime FROM {$_TABLES['tokens']} WHERE (token = '$token') AND (owner_id = '{$_USER['uid']}') AND (ttl > 0)";
+
+        $result = DB_query($sql);
+        if (DB_numRows($result) == 1) {
+            list($retval) = DB_fetchArray($result);
+        }
+    }
+
+    return $retval;
+}
+
+/**
+* Create a message informing the user when the security token is about to expire
+*
+* @param    string  $token      the token
+* @param    string  $extra_msg  (optional) additional text to include in notice
+* @return   string              formatted HTML of message
+*
+*/
+function SEC_getTokenExpiryNotice($token, $extra_msg = '')
+{
+    global $_CONF, $LANG_ADMIN;
+
+    $retval = '';
+
+    $expirytime = SEC_getTokenExpiryTime($token);
+    if ($expirytime > 0) {
+        $exptime = '<span id="token-expirytime">'
+                 . strftime($_CONF['timeonly'], $expirytime) . '</span>';
+        $retval .= '<p id="token-expirynotice">'
+                . sprintf($LANG_ADMIN['token_expiry'], $exptime);
+        if (! empty($extra_msg)) {
+            $retval .= ' ' . $extra_msg;
+        }
+
+        $retval .= '</p>' . LB;
+    }
+
+    return $retval;
+}
+
+/**
+* Set a cookie using the HttpOnly flag
+*
+* Use this function to set "important" cookies (session, password, ...).
+* Browsers that support the HttpOnly flag will not allow JavaScript access
+* to such a cookie.
+*
+* @param    string  $name       cookie name
+* @param    string  $value      cookie value
+* @param    int     $expire     expire time
+* @param    string  $path       path on the server or $_CONF['cookie_path']
+* @param    string  $domain     domain or $_CONF['cookiedomain']
+* @param    bool    $secure     whether to use HTTPS or $_CONF['cookiesecure']
+* @link http://blog.mattmecham.com/2006/09/12/http-only-cookies-without-php-52/
+*
+*/
+function SEC_setCookie($name, $value, $expire = 0, $path = null, $domain = null, $secure = null)
+{
+    global $_CONF;
+
+    $retval = false;
+
+    if ($path === null) {
+        $path = $_CONF['cookie_path'];
+    }
+    if ($domain === null) {
+        $domain = $_CONF['cookiedomain'];
+    }
+    if ($secure === null) {
+        $secure = $_CONF['cookiesecure'];
+    }
+
+    // the httponly parameter is only available as of PHP 5.2.0
+    if (version_compare(PHP_VERSION, '5.2.0', '>=')) {
+        $retval = setcookie($name, $value, $expire, $path, $domain, $secure,
+                            true);
+    } else {
+        // fake it for older PHP versions; kudos to Matt Mecham
+        $retval = setcookie($name, $value, $expire, $path,
+                            $domain . '; httponly', $secure);
+    }
+
+    return $retval;
+}
+
+/**
+* Prepare an array of the standard permission values
+*
+* This helper functions does the following:
+* 1) filter permission values, e.g. after a POST request
+* 2) translates the permission checkbox arrays into numerical values
+* 3) ensures that all the standard permission entries are set, so you don't
+*    have to check with isset() all the time
+*
+* <code>
+* $PERM = SEC_filterPermissions($_POST);
+* if ($PERM['perm_anon'] != 0) { ...
+* </code>
+*
+* @param    array   $A  array to filter on, e.g. $_POST
+* @return   array       array of only the 6 standard permission values
+* @see      SEC_getPermissionValues
+*
+*/
+function SEC_filterPermissions($A)
+{
+    $retval = array();
+
+    if (isset($A['owner_id'])) {
+        $retval['owner_id'] = COM_applyFilter($A['owner_id'], true);
+    } else {
+        $retval['owner_id'] = 0;
+    }
+
+    if (isset($A['group_id'])) {
+        $retval['group_id'] = COM_applyFilter($A['group_id'], true);
+    } else {
+        $retval['group_id'] = 0;
+    }
+
+    $perms = array('perm_owner', 'perm_group', 'perm_members', 'perm_anon');
+
+    $B = array();
+    foreach ($perms as $p) {
+        if (isset($A[$p])) {
+            $B[$p] = $A[$p];
+        } else {
+            $B[$p] = array();
+        }
+    }
+
+    $B = SEC_getPermissionValues($B['perm_owner'], $B['perm_group'],
+                                 $B['perm_members'], $B['perm_anon']);
+    for ($i = 0; $i < 4; $i++) {
+        $retval[$perms[$i]] = $B[$i];
+    }
+
+    return $retval;
+}
+
+/**
+* Helper function for when you want to call SEC_hasAccess and have all the
+* values to check in an array.
+*
+* @param    array   $A  array with the standard permission values
+* @return   int         returns 3 for read/edit 2 for read only 0 for no access
+* @see      SEC_hasAccess
+*
+*/
+function SEC_hasAccess2($A)
+{
+    return SEC_hasAccess($A['owner_id'], $A['group_id'], $A['perm_owner'],
+                         $A['perm_group'], $A['perm_members'], $A['perm_anon']);
+}
+
 ?>
